/*
 * Copyright (C) 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.settings.testutils;

import android.content.Context;

import com.android.settings.R;
import com.android.settings.search.BaseSearchIndexProvider;
import com.android.settingslib.search.Indexable;

import java.util.List;

public class FakeIndexProvider implements Indexable {

    public static final String KEY = "TestKey";

    /**
     * The fake SearchIndexProvider. Note that the use of location_settings below implies that tests
     * using this should be using the res/xml-mcc999/location_settings.xml or
     * res/xml-mcc998/location_settings.xml. Annotate tests with
     * {@code @Config(qualifiers = "mcc999")}.
     */
    public static final BaseSearchIndexProvider SEARCH_INDEX_DATA_PROVIDER =
            new BaseSearchIndexProvider(R.xml.location_settings) {

                @Override
                public List<String> getNonIndexableKeys(Context context) {
                    List<String> result = super.getNonIndexableKeys(context);
                    result.add(KEY);
                    return result;
                }
            };
}
